@@ -45,7 +45,7 @@ class BaseMessageAdmin(admin.ModelAdmin[BaseMessage]):
             return ("id", "default", "default_plural", "context", "is_used")
 
         fields = ["id", "default"]
-        if obj.default_plural != obj.default:
+        if obj.default_plural and obj.default_plural != obj.default:
             fields.append("default_plural")
 
         if obj.context:
